mtls

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 8, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MTLSAuth

type MTLSAuth struct{}

func (*MTLSAuth) Authenticate

func (m *MTLSAuth) Authenticate(ctx context.Context, r *http.Request, p interface{}) bool

func (*MTLSAuth) Identify

func (m *MTLSAuth) Identify(r *http.Request, p interface{}) (string, bool)

func (*MTLSAuth) Name

func (m *MTLSAuth) Name() string

func (*MTLSAuth) OptionalParams

func (m *MTLSAuth) OptionalParams() []string

func (*MTLSAuth) ParseParams

func (m *MTLSAuth) ParseParams(data map[string]interface{}) (interface{}, error)

func (*MTLSAuth) RequiredParams

func (m *MTLSAuth) RequiredParams() []string

type MTLSAuthOut

type MTLSAuthOut struct{}

func (*MTLSAuthOut) AddAuth

func (m *MTLSAuthOut) AddAuth(ctx context.Context, r *http.Request, p interface{}) error

AddAuth exposes the configured client certificate's common name to the backend via the "X-TLS-Client-CN" header. This allows upstream services to easily identify the client certificate used for the mTLS connection.

func (*MTLSAuthOut) Name

func (m *MTLSAuthOut) Name() string

func (*MTLSAuthOut) OptionalParams

func (m *MTLSAuthOut) OptionalParams() []string

func (*MTLSAuthOut) ParseParams

func (m *MTLSAuthOut) ParseParams(mp map[string]interface{}) (interface{}, error)

func (*MTLSAuthOut) RequiredParams

func (m *MTLSAuthOut) RequiredParams() []string

func (*MTLSAuthOut) Transport

func (m *MTLSAuthOut) Transport(p interface{}) *http.Transport

Transport exposes the configured mTLS transport for integration usage.

Jump to