Documentation
¶
Index ¶
- type MTLSAuth
- func (m *MTLSAuth) Authenticate(ctx context.Context, r *http.Request, p interface{}) bool
- func (m *MTLSAuth) Identify(r *http.Request, p interface{}) (string, bool)
- func (m *MTLSAuth) Name() string
- func (m *MTLSAuth) OptionalParams() []string
- func (m *MTLSAuth) ParseParams(data map[string]interface{}) (interface{}, error)
- func (m *MTLSAuth) RequiredParams() []string
- type MTLSAuthOut
- func (m *MTLSAuthOut) AddAuth(ctx context.Context, r *http.Request, p interface{}) error
- func (m *MTLSAuthOut) Name() string
- func (m *MTLSAuthOut) OptionalParams() []string
- func (m *MTLSAuthOut) ParseParams(mp map[string]interface{}) (interface{}, error)
- func (m *MTLSAuthOut) RequiredParams() []string
- func (m *MTLSAuthOut) Transport(p interface{}) *http.Transport
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MTLSAuth ¶
type MTLSAuth struct{}
func (*MTLSAuth) Authenticate ¶
func (*MTLSAuth) OptionalParams ¶
func (*MTLSAuth) ParseParams ¶
func (*MTLSAuth) RequiredParams ¶
type MTLSAuthOut ¶
type MTLSAuthOut struct{}
func (*MTLSAuthOut) AddAuth ¶
AddAuth exposes the configured client certificate's common name to the backend via the "X-TLS-Client-CN" header. This allows upstream services to easily identify the client certificate used for the mTLS connection.
func (*MTLSAuthOut) Name ¶
func (m *MTLSAuthOut) Name() string
func (*MTLSAuthOut) OptionalParams ¶
func (m *MTLSAuthOut) OptionalParams() []string
func (*MTLSAuthOut) ParseParams ¶
func (m *MTLSAuthOut) ParseParams(mp map[string]interface{}) (interface{}, error)
func (*MTLSAuthOut) RequiredParams ¶
func (m *MTLSAuthOut) RequiredParams() []string
func (*MTLSAuthOut) Transport ¶
func (m *MTLSAuthOut) Transport(p interface{}) *http.Transport
Transport exposes the configured mTLS transport for integration usage.
Click to show internal directories.
Click to hide internal directories.