Documentation
¶
Index ¶
- func List() []string
- func Register(name string, b Builder)
- type AuthPluginConfig
- type Builder
- type Integration
- func Asana(name, tokenRef string) Integration
- func Confluence(name, tokenRef, domain string) Integration
- func GitHub(name, tokenRef, webhookSecretRef string) Integration
- func GitHubEnterprise(name, domain, tokenRef, webhookSecretRef string) Integration
- func GitLab(name, tokenRef string) Integration
- func Jira(name, tokenRef, domain string) Integration
- func Linear(name, tokenRef string) Integration
- func Monday(name, tokenRef string) Integration
- func Okta(name, domain, tokenRef string) Integration
- func OpenAI(name, tokenRef string) Integration
- func SendGrid(name, tokenRef string) Integration
- func ServiceNow(name, tokenRef string) Integration
- func Slack(name, tokenRef, signingSecretRef string) Integration
- func Stripe(name, tokenRef string) Integration
- func TruffleHog(name, tokenRef string) Integration
- func Twilio(name, tokenRef string) Integration
- func Workday(name, domain, tokenRef string) Integration
- func Zendesk(name, tokenRef string) Integration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AuthPluginConfig ¶
type AuthPluginConfig struct {
Type string `json:"type" yaml:"type"`
Params map[string]interface{} `json:"params" yaml:"params"`
}
AuthPluginConfig mirrors the main application's plugin config.
type Builder ¶
type Builder func(args []string) (Integration, error)
Builder defines a function that parses CLI args into an Integration.
type Integration ¶
type Integration struct {
Name string `json:"name" yaml:"name"`
Destination string `json:"destination" yaml:"destination"`
InRateLimit int `json:"in_rate_limit" yaml:"in_rate_limit"`
OutRateLimit int `json:"out_rate_limit" yaml:"out_rate_limit"`
IncomingAuth []AuthPluginConfig `json:"incoming_auth" yaml:"incoming_auth"`
OutgoingAuth []AuthPluginConfig `json:"outgoing_auth" yaml:"outgoing_auth"`
}
Integration mirrors the main application's integration structure.
func Asana ¶
func Asana(name, tokenRef string) Integration
Asana returns an Integration configured for the Asana API.
func Confluence ¶
func Confluence(name, tokenRef, domain string) Integration
Confluence returns an Integration configured for the Confluence API. The domain argument is optional and defaults to api.atlassian.com.
func GitHub ¶
func GitHub(name, tokenRef, webhookSecretRef string) Integration
GitHub returns an Integration configured for the GitHub API.
func GitHubEnterprise ¶
func GitHubEnterprise(name, domain, tokenRef, webhookSecretRef string) Integration
GitHubEnterprise returns an Integration configured for a GitHub Enterprise instance.
func GitLab ¶
func GitLab(name, tokenRef string) Integration
GitLab returns an Integration configured for the GitLab API.
func Jira ¶
func Jira(name, tokenRef, domain string) Integration
Jira returns an Integration configured for the Jira API. The domain argument is optional and defaults to api.atlassian.com.
func Linear ¶
func Linear(name, tokenRef string) Integration
Linear returns an Integration configured for the Linear API.
func Monday ¶
func Monday(name, tokenRef string) Integration
Monday returns an Integration configured for the monday.com API.
func Okta ¶
func Okta(name, domain, tokenRef string) Integration
Okta returns an Integration configured for the Okta API.
func OpenAI ¶
func OpenAI(name, tokenRef string) Integration
OpenAI returns an Integration configured for the OpenAI API.
func SendGrid ¶
func SendGrid(name, tokenRef string) Integration
SendGrid returns an Integration configured for the SendGrid API.
func ServiceNow ¶
func ServiceNow(name, tokenRef string) Integration
ServiceNow returns an Integration configured for the ServiceNow API.
func Slack ¶
func Slack(name, tokenRef, signingSecretRef string) Integration
Slack returns an Integration configured for the Slack API.
func Stripe ¶
func Stripe(name, tokenRef string) Integration
Stripe returns an Integration configured for the Stripe API.
func TruffleHog ¶
func TruffleHog(name, tokenRef string) Integration
TruffleHog returns an Integration configured for the TruffleHog API.
func Twilio ¶
func Twilio(name, tokenRef string) Integration
Twilio returns an Integration configured for the Twilio API.
func Workday ¶
func Workday(name, domain, tokenRef string) Integration
Workday returns an Integration configured for the Workday API.
func Zendesk ¶
func Zendesk(name, tokenRef string) Integration
Zendesk returns an Integration configured for the Zendesk API.